@@ -732,6 +732,7 @@ void do_execute (const char *shell, const char *command, int internal_command)
 {
 #ifdef HAVE_SUBSHELL_SUPPORT
     char *new_dir = NULL;
+    char **new_dir_p;
 #ifdef USE_VFS
     char *old_vfs_dir = 0;
 
@@ -756,7 +757,8 @@ void do_execute (const char *shell, const char *command, int internal_command)
 	do_update_prompt ();
 
 	/* We don't care if it died, higher level takes care of this */
-	invoke_subshell (command, VISIBLY, &new_dir);
+	new_dir_p = vfs_current_is_local () ? &new_dir : NULL;
+	invoke_subshell (command, VISIBLY, new_dir_p);
     } else
 #endif
 	my_system (!internal_command, shell, command);
